#  SPDX-FileCopyrightText: Copyright (c) "2024" NVIDIA CORPORATION & AFFILIATES. All rights reserved.
#  SPDX-License-Identifier: Apache-2.0
#
#  Licensed under the Apache License, Version 2.0 (the "License")
#  you may not use this file except in compliance with the License.
#  You may obtain a copy of the License at
#
#  http://www.apache.org/licenses/LICENSE-2.0
#
#  Unless required by applicable law or agreed to in writing, software
#  distributed under the License is distributed on an "AS IS" BASIS
#  WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
#  See the License for the specific language governing permissions and
#  limitations under the License.

"""Form definitions for the Nautobot FSUs app."""
from nautobot_fsus.forms.fsu_templates import (
    CPUTemplateBulkEditForm,
    CPUTemplateCSVForm,
    CPUTemplateCreateForm,
    CPUTemplateForm,
    DiskTemplateBulkEditForm,
    DiskTemplateCSVForm,
    DiskTemplateCreateForm,
    DiskTemplateForm,
    FanTemplateBulkEditForm,
    FanTemplateCSVForm,
    FanTemplateCreateForm,
    FanTemplateForm,
    GPUBaseboardTemplateBulkEditForm,
    GPUBaseboardTemplateCSVForm,
    GPUBaseboardTemplateCreateForm,
    GPUBaseboardTemplateForm,
    GPUTemplateBulkEditForm,
    GPUTemplateCSVForm,
    GPUTemplateCreateForm,
    GPUTemplateForm,
    HBATemplateBulkEditForm,
    HBATemplateCSVForm,
    HBATemplateCreateForm,
    HBATemplateForm,
    MainboardTemplateBulkEditForm,
    MainboardTemplateCSVForm,
    MainboardTemplateCreateForm,
    MainboardTemplateForm,
    NICTemplateBulkEditForm,
    NICTemplateCSVForm,
    NICTemplateCreateForm,
    NICTemplateForm,
    OtherFSUTemplateBulkEditForm,
    OtherFSUTemplateCSVForm,
    OtherFSUTemplateCreateForm,
    OtherFSUTemplateForm,
    PSUTemplateBulkEditForm,
    PSUTemplateCSVForm,
    PSUTemplateCreateForm,
    PSUTemplateForm,
    RAMModuleTemplateBulkEditForm,
    RAMModuleTemplateCSVForm,
    RAMModuleTemplateCreateForm,
    RAMModuleTemplateForm,
)
from nautobot_fsus.forms.fsu_types import (
    CPUTypeBulkEditForm,
    CPUTypeCSVForm,
    CPUTypeFilterForm,
    CPUTypeForm,
    CPUTypeImportForm,
    DiskTypeBulkEditForm,
    DiskTypeCSVForm,
    DiskTypeFilterForm,
    DiskTypeForm,
    DiskTypeImportForm,
    FanTypeBulkEditForm,
    FanTypeCSVForm,
    FanTypeFilterForm,
    FanTypeForm,
    FanTypeImportForm,
    GPUBaseboardTypeBulkEditForm,
    GPUBaseboardTypeCSVForm,
    GPUBaseboardTypeFilterForm,
    GPUBaseboardTypeForm,
    GPUBaseboardTypeImportForm,
    GPUTypeBulkEditForm,
    GPUTypeCSVForm,
    GPUTypeFilterForm,
    GPUTypeForm,
    GPUTypeImportForm,
    HBATypeBulkEditForm,
    HBATypeCSVForm,
    HBATypeFilterForm,
    HBATypeForm,
    HBATypeImportForm,
    MainboardTypeBulkEditForm,
    MainboardTypeCSVForm,
    MainboardTypeFilterForm,
    MainboardTypeForm,
    MainboardTypeImportForm,
    NICTypeBulkEditForm,
    NICTypeCSVForm,
    NICTypeFilterForm,
    NICTypeForm,
    NICTypeImportForm,
    OtherFSUTypeBulkEditForm,
    OtherFSUTypeCSVForm,
    OtherFSUTypeFilterForm,
    OtherFSUTypeForm,
    OtherFSUTypeImportForm,
    PSUTypeBulkEditForm,
    PSUTypeCSVForm,
    PSUTypeFilterForm,
    PSUTypeForm,
    PSUTypeImportForm,
    RAMModuleTypeBulkEditForm,
    RAMModuleTypeCSVForm,
    RAMModuleTypeFilterForm,
    RAMModuleTypeForm,
    RAMModuleTypeImportForm,
)
from nautobot_fsus.forms.fsus import (
    CPUBulkEditForm,
    CPUCSVForm,
    CPUFilterForm,
    CPUForm,
    CPUImportForm,
    DiskBulkEditForm,
    DiskCSVForm,
    DiskFilterForm,
    DiskForm,
    DiskImportForm,
    FanBulkEditForm,
    FanCSVForm,
    FanFilterForm,
    FanForm,
    FanImportForm,
    GPUBaseboardBulkEditForm,
    GPUBaseboardCSVForm,
    GPUBaseboardFilterForm,
    GPUBaseboardForm,
    GPUBaseboardImportForm,
    GPUBulkEditForm,
    GPUCSVForm,
    GPUFilterForm,
    GPUForm,
    GPUImportForm,
    HBABulkEditForm,
    HBACSVForm,
    HBAFilterForm,
    HBAForm,
    HBAImportForm,
    MainboardBulkEditForm,
    MainboardCSVForm,
    MainboardFilterForm,
    MainboardForm,
    MainboardImportForm,
    NICBulkEditForm,
    NICCSVForm,
    NICFilterForm,
    NICForm,
    NICImportForm,
    OtherFSUBulkEditForm,
    OtherFSUCSVForm,
    OtherFSUFilterForm,
    OtherFSUForm,
    OtherFSUImportForm,
    PSUBulkEditForm,
    PSUCSVForm,
    PSUFilterForm,
    PSUForm,
    PSUImportForm,
    RAMModuleBulkEditForm,
    RAMModuleCSVForm,
    RAMModuleFilterForm,
    RAMModuleForm,
    RAMModuleImportForm,
)

__all__ = (
    "CPUBulkEditForm",
    "CPUCSVForm",
    "CPUFilterForm",
    "CPUForm",
    "CPUImportForm",
    "CPUTemplateBulkEditForm",
    "CPUTemplateCSVForm",
    "CPUTemplateCreateForm",
    "CPUTemplateForm",
    "CPUTypeBulkEditForm",
    "CPUTypeCSVForm",
    "CPUTypeFilterForm",
    "CPUTypeForm",
    "CPUTypeImportForm",
    "DiskBulkEditForm",
    "DiskCSVForm",
    "DiskFilterForm",
    "DiskForm",
    "DiskImportForm",
    "DiskTemplateBulkEditForm",
    "DiskTemplateCSVForm",
    "DiskTemplateCreateForm",
    "DiskTemplateForm",
    "DiskTypeBulkEditForm",
    "DiskTypeCSVForm",
    "DiskTypeFilterForm",
    "DiskTypeForm",
    "DiskTypeImportForm",
    "FanBulkEditForm",
    "FanCSVForm",
    "FanFilterForm",
    "FanForm",
    "FanImportForm",
    "FanTemplateBulkEditForm",
    "FanTemplateCSVForm",
    "FanTemplateCreateForm",
    "FanTemplateForm",
    "FanTypeBulkEditForm",
    "FanTypeCSVForm",
    "FanTypeFilterForm",
    "FanTypeForm",
    "FanTypeImportForm",
    "GPUBaseboardBulkEditForm",
    "GPUBaseboardCSVForm",
    "GPUBaseboardFilterForm",
    "GPUBaseboardForm",
    "GPUBaseboardImportForm",
    "GPUBaseboardTemplateBulkEditForm",
    "GPUBaseboardTemplateCSVForm",
    "GPUBaseboardTemplateCreateForm",
    "GPUBaseboardTemplateForm",
    "GPUBaseboardTypeBulkEditForm",
    "GPUBaseboardTypeCSVForm",
    "GPUBaseboardTypeFilterForm",
    "GPUBaseboardTypeForm",
    "GPUBaseboardTypeImportForm",
    "GPUBulkEditForm",
    "GPUCSVForm",
    "GPUFilterForm",
    "GPUForm",
    "GPUImportForm",
    "GPUTemplateBulkEditForm",
    "GPUTemplateCSVForm",
    "GPUTemplateCreateForm",
    "GPUTemplateForm",
    "GPUTypeBulkEditForm",
    "GPUTypeCSVForm",
    "GPUTypeFilterForm",
    "GPUTypeForm",
    "GPUTypeImportForm",
    "HBABulkEditForm",
    "HBACSVForm",
    "HBAFilterForm",
    "HBAForm",
    "HBAImportForm",
    "HBATemplateBulkEditForm",
    "HBATemplateCSVForm",
    "HBATemplateCreateForm",
    "HBATemplateForm",
    "HBATypeBulkEditForm",
    "HBATypeCSVForm",
    "HBATypeFilterForm",
    "HBATypeForm",
    "HBATypeImportForm",
    "MainboardBulkEditForm",
    "MainboardCSVForm",
    "MainboardFilterForm",
    "MainboardForm",
    "MainboardImportForm",
    "MainboardTemplateBulkEditForm",
    "MainboardTemplateCSVForm",
    "MainboardTemplateCreateForm",
    "MainboardTemplateForm",
    "MainboardTypeBulkEditForm",
    "MainboardTypeCSVForm",
    "MainboardTypeFilterForm",
    "MainboardTypeForm",
    "MainboardTypeImportForm",
    "NICBulkEditForm",
    "NICCSVForm",
    "NICFilterForm",
    "NICForm",
    "NICImportForm",
    "NICTemplateBulkEditForm",
    "NICTemplateCSVForm",
    "NICTemplateCreateForm",
    "NICTemplateForm",
    "NICTypeBulkEditForm",
    "NICTypeCSVForm",
    "NICTypeFilterForm",
    "NICTypeForm",
    "NICTypeImportForm",
    "OtherFSUBulkEditForm",
    "OtherFSUCSVForm",
    "OtherFSUFilterForm",
    "OtherFSUForm",
    "OtherFSUImportForm",
    "OtherFSUTemplateBulkEditForm",
    "OtherFSUTemplateCSVForm",
    "OtherFSUTemplateCreateForm",
    "OtherFSUTemplateForm",
    "OtherFSUTypeBulkEditForm",
    "OtherFSUTypeCSVForm",
    "OtherFSUTypeFilterForm",
    "OtherFSUTypeForm",
    "OtherFSUTypeImportForm",
    "PSUBulkEditForm",
    "PSUCSVForm",
    "PSUFilterForm",
    "PSUForm",
    "PSUImportForm",
    "PSUTemplateBulkEditForm",
    "PSUTemplateCSVForm",
    "PSUTemplateCreateForm",
    "PSUTemplateForm",
    "PSUTypeBulkEditForm",
    "PSUTypeCSVForm",
    "PSUTypeFilterForm",
    "PSUTypeForm",
    "PSUTypeImportForm",
    "RAMModuleBulkEditForm",
    "RAMModuleCSVForm",
    "RAMModuleFilterForm",
    "RAMModuleForm",
    "RAMModuleImportForm",
    "RAMModuleTemplateBulkEditForm",
    "RAMModuleTemplateCSVForm",
    "RAMModuleTemplateCreateForm",
    "RAMModuleTemplateForm",
    "RAMModuleTypeBulkEditForm",
    "RAMModuleTypeCSVForm",
    "RAMModuleTypeFilterForm",
    "RAMModuleTypeForm",
    "RAMModuleTypeImportForm",
)
